@@ -1,4 +1,3 @@
-import json
 import os
 
 from . import exceptions
@@ -128,6 +127,10 @@ def load_plugins(config, defaults):
             defaults[plugin.config_key(key)] = value
 
 
+def is_service_activated(config, service):
+    return config["ACTIVATE_" + service.upper()]
+
+
 def upgrade_obsolete(config):
     # Openedx-specific mysql passwords
     if "MYSQL_PASSWORD" in config:
